from os.path import abspath, join
import json
import subprocess

from django.conf import settings

from ._base import EmberCommand


class Command(EmberCommand):
    help = (
        'Generate the backend-config.js file, so that Ember knows where to '
        'find the API')

    def handle(self, *args, **options):
        self.assert_required_settings('EMBER_APP_PATH', 'API_PATH')

        config_path = abspath(join(
            self.get_full_ember_path(),
            'config/backend-config.js'))

        self.notify('Generating Ember configuration at: \n' + config_path)

        config_data = {
            'apiHost': 'http://localhost:4200',
            'apiPath': self.get_setting('API_PATH')
        }

        config_source = '//automatically generated by backend -- do not edit'
        config_source += '\n' + 'module.exports =' + json.dumps(config_data)
        config_source += ';\n'

        with open(config_path, 'w') as config_file:
            config_file.write(config_source)
